@@ -10,14 +10,14 @@ var searchData=
   ['uno_5fenterable_5fisvalid_5fv_7',['uno_Enterable_isValid_v',['../a00260.html#ab0a2639a88519e99402b5e98bb5dbf3b',1,'Enterable.h']]],
   ['uno_5fenterable_5fleave_8',['uno_Enterable_leave',['../a00260.html#a43424074f509960815ee7e5034b3a959',1,'Enterable.h']]],
   ['uno_5fenvcallee_9',['uno_EnvCallee',['../a00284.html#ab9b865bd93a54c6b944a0c2a7e56563b',1,'environment.h']]],
-  ['uno_5fenvironment_10',['uno_Environment',['../a00389.html#a74e26b81b7e694cdfdba825489dcb1cb',1,'uno_Environment():&#160;factory.hxx'],['../a00284.html#a0057727f6a3e4c9381f41d0d53f6bc20',1,'uno_Environment():&#160;environment.h']]],
+  ['uno_5fenvironment_10',['uno_Environment',['../a00284.html#a0057727f6a3e4c9381f41d0d53f6bc20',1,'uno_Environment():&#160;environment.h'],['../a00389.html#a74e26b81b7e694cdfdba825489dcb1cb',1,'uno_Environment():&#160;factory.hxx']]],
   ['uno_5fext_5fgetmappingfunc_11',['uno_ext_getMappingFunc',['../a00293.html#acb7eed6ff94dfcaebc5d3c659a04726f',1,'mapping.h']]],
   ['uno_5fextenvironment_12',['uno_ExtEnvironment',['../a00284.html#a6b8ac7393f2c17002b1bb91c0be01c1b',1,'environment.h']]],
   ['uno_5ffreemappingfunc_13',['uno_freeMappingFunc',['../a00293.html#ae0198eda21db3f3ff5ac8ddb878d38c2',1,'mapping.h']]],
   ['uno_5ffreeproxyfunc_14',['uno_freeProxyFunc',['../a00284.html#a2ffa03a636a5dd3845056056a1dca05b',1,'environment.h']]],
   ['uno_5fgetmappingfunc_15',['uno_getMappingFunc',['../a00293.html#af7d3d95e35e4e1bab13a5af55cca4c42',1,'mapping.h']]],
   ['uno_5finitenvironmentfunc_16',['uno_initEnvironmentFunc',['../a00284.html#a65fa1b1ce1d750173fdeac329953240f',1,'environment.h']]],
-  ['uno_5finterface_17',['uno_Interface',['../a00278.html#a01e8e71e2517bfaf724992d49a7319d2',1,'uno_Interface():&#160;dispatcher.h'],['../a02521.html#a5d48d6cca53bfac7c4e87cd815059a0e',1,'uno_Interface():&#160;mapping.hxx']]],
+  ['uno_5finterface_17',['uno_Interface',['../a00278.html#a01e8e71e2517bfaf724992d49a7319d2',1,'uno_Interface():&#160;dispatcher.h'],['../a02525.html#a5d48d6cca53bfac7c4e87cd815059a0e',1,'uno_Interface():&#160;mapping.hxx']]],
   ['uno_5fmapinterfacefunc_18',['uno_MapInterfaceFunc',['../a00293.html#aa7d6cb720868db0b34be2d06e84b52c6',1,'mapping.h']]],
   ['uno_5fmapping_19',['uno_Mapping',['../a00293.html#abe84c421515210d4c58d23656bf77a6e',1,'mapping.h']]],
   ['uno_5fmemalloc_20',['uno_memAlloc',['../a00284.html#a601137e3ecc972111d489346f3d72325',1,'environment.h']]],
